@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/jra1mw/org.glite.lb.common/src/context.c,v 1.62 2012/08/08 10:21:03 mvocu Exp $"
+#ident "$Header: /cvs/glite/org.glite.lb.common/src/context.c,v 1.66 2012/09/11 09:44:31 zsustr Exp $"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -63,6 +63,7 @@ int edg_wll_InitContext(edg_wll_Context *ctx)
 	edg_wll_initConnNotif(out->connNotif);
 	out->connProxy->conn.sock = -1;
 //	out->connToUse = -1;
+	out->id_mapping.num = 0;
 
 	memset(&null, 0, sizeof null);
 	for (i=0; i<EDG_WLL_PARAM__LAST; i++) {
@@ -192,6 +193,14 @@ void edg_wll_FreeContext(edg_wll_Context ctx)
 		}
 		free (ctx->authz_policy.actions);
 	}
+	if (ctx->id_mapping.num) {
+		for (i = 0; i < ctx->id_mapping.num; i++) {
+			free(ctx->id_mapping.rules[i].a);
+			free(ctx->id_mapping.rules[i].b);
+		}
+		free(ctx->id_mapping.rules);
+		ctx->id_mapping.num = 0;
+	}
 	
 	if (ctx->jpreg_dir) free(ctx->jpreg_dir);
 	if (ctx->serverIdentity) free(ctx->serverIdentity);
@@ -352,7 +361,10 @@ static const char* const srcNames[] = {
 	"PBSServer",
 	"PBSMomSuperior",
 	"PBSMom",
-	"PBSScheduler"
+	"PBSScheduler",
+	"CloudManager",
+	"VMManager",
+	"VMSystem"
 };
 
 edg_wll_Source edg_wll_StringToSource(const char *name)
