@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/jra1mw/org.glite.lb.common/src/query_rec.c,v 1.17 2012/08/09 14:50:40 zsustr Exp $"
+#ident "$Header: /cvs/glite/org.glite.lb.common/src/query_rec.c,v 1.18 2013/01/04 14:04:05 jfilipov Exp $"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -35,7 +35,7 @@ char     *edg_wll_QueryAttrNames[] = {    "undef", "jobid","owner","status","loc
                                 "donecode","usertag","time","level","host","source",
                                 "instance","type","chkpt_tag", "resubmitted", "parent_job",
                                 "exitcode", "jdl", "stateentertime", "lastupdatetime",
-                                "networkserver", "jobtype"  };
+                                "networkserver", "jobtype", "vm_status"  };
 
 /**
  * Names for the predefined types of query operands
@@ -79,6 +79,7 @@ void edg_wll_QueryRecFree(edg_wll_QueryRec *prec)
 		case EDG_WLL_QUERY_ATTR_STATEENTERTIME:
 		case EDG_WLL_QUERY_ATTR_LASTUPDATETIME:
 		case EDG_WLL_QUERY_ATTR_JOB_TYPE:
+		case EDG_WLL_QUERY_ATTR_VM_STATUS:
 			/* do nothing */
 			break;
 		default:
