@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/jra1mw/org.glite.lb.common/src/xml_conversions.c,v 1.26 2012/08/08 15:48:40 zsustr Exp $"
+#ident "$Header: /cvs/glite/org.glite.lb.common/src/xml_conversions.c,v 1.28 2013/01/25 15:17:23 valtri Exp $"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -28,8 +28,6 @@ limitations under the License.
 #include "jobstat.h"
 
 
-extern char *edg_wll_TagListToString(edg_wll_TagValue *);
-
 static const struct timeval null_timeval = {0,0};
 
 
@@ -273,6 +271,21 @@ void edg_wll_add_edg_wll_JobStatCode_to_XMLBody(char **body, edg_wll_JobStatCode
 	}
 }
 
+void edg_wll_add_edg_wll_StatVm_state_to_XMLBody(char **body, enum edg_wll_StatVm_state toAdd, const char *tag, const enum edg_wll_StatVm_state null)
+{
+        if (toAdd != null) {
+                char *newBody, *pom;
+
+                trio_asprintf(&newBody,"%s\t\t\t<%s>%|Xs</%s>\r\n",
+                        *body, tag, pom = edg_wll_VMStatToString(toAdd), tag);
+
+                free(*body);
+                free(pom);
+                *body = newBody;
+        }
+}
+
+
 void edg_wll_add_edg_wll_EventCode_to_XMLBody(char **body, edg_wll_EventCode toAdd, const char *tag, const edg_wll_EventCode null)
 {
 	char *newBody, *pom;
@@ -638,6 +651,23 @@ edg_wll_JobStatCode edg_wll_from_string_to_edg_wll_JobStatCode(edg_wll_XML_ctx *
 
 
 
+enum edg_wll_StatVm_state edg_wll_from_string_to_edg_wll_StatVm_state(edg_wll_XML_ctx *XMLCtx)
+{
+        edg_wll_JobStatCode out = -1;
+        char *s;
+
+        s = glite_lbu_UnescapeXML((const char *) XMLCtx->char_buf);
+        if (s) {
+           out = edg_wll_StringToVMStat(s);
+           free(s);
+        }
+        edg_wll_freeBuf(XMLCtx);
+
+        return(out);
+}
+
+
+
 enum edg_wll_StatJobtype edg_wll_from_string_to_edg_wll_StatJobtype(edg_wll_XML_ctx *XMLCtx)
 {
         enum edg_wll_StatJobtype out = -1;
@@ -775,7 +805,8 @@ void *edg_wll_from_string_to_cclassad(edg_wll_XML_ctx *XMLCtx)
 
 edg_wll_TagValue *edg_wll_from_string_to_taglist(edg_wll_XML_ctx *XMLCtx)
 {
-	char *s, *out = NULL;
+	char *s;
+	edg_wll_TagValue *out = NULL;
 
 	s = glite_lbu_UnescapeXML((const char*) XMLCtx->char_buf);
 	if(s) {
@@ -993,6 +1024,7 @@ static const char * const query_attrConsts[] = {
 	"EDG_WLL_QUERY_ATTR_STATEENTERTIME",
 	"EDG_WLL_QUERY_ATTR_LASTUPDATETIME",
         "EDG_WLL_QUERY_ATTR_JOB_TYPE",
+	"EDG_WLL_QUERY_ATTR_VM_STATUS",
         "EDG_WLL_QUERY_ATTR__LAST",
 };
 
